yakumo.neutron.v2.lbaas.listener.Manager

Package yakumo :: Package neutron :: Package v2 :: Package lbaas :: Module listener :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
     base.SubManager --+
                       |
                      Manager

Manager class for LBaaS listeners in Networking V2 API

Nested Classes | [hide private]
| resource_class Resource class for LBaaS listeners in Networking V2 API

Instance Methods | [hide private]
yakumo.neutron.v2.lbaas.listener.Resource |
create(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, protocol=`'``__UNDEF__``'`, protocol_port=`'``__UNDEF__``'`, connection_limit=`'``__UNDEF__``'`, default_tls_container_ref=`'``__UNDEF__``'`, sni_container_refs=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`) Create a listener for LBaaS | source code
Inherited from `base.SubManager`: `__init__` Inherited from `base.Manager`: `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``network``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _json_resource_key = ``'``listener``'``
| _json_resources_key = ``'``listeners``'``
| _url_resource_path = ``'``/v2.0/lbaas/listeners``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_hidden_methods`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, protocol=`'``__UNDEF__``'`, protocol_port=`'``__UNDEF__``'`, connection_limit=`'``__UNDEF__``'`, default_tls_container_ref=`'``__UNDEF__``'`, sni_container_refs=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`) | source code
Create a listener for LBaaS Parameters: `name` (str) - Listener name `description` (str) - Description `protocol` (str) - Protocol ('TCP', 'UDP', 'HTTP' or 'HTTPS') `protocol_port` (int) - Protocol port number `connection_limit` (int) - Maximun connection number `default_tls_container_ref` (str) - A reference to a container of TLS secrets `sni_container_refs` (str) - A list of references to TLS secrets `project` (yakumo.project.Resource) - Project `is_enabled` (bool) - Whether the listner is enabled Returns: yakumo.neutron.v2.lbaas.listener.Resource Created listener Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('descripti
      on', 'description', mapper.Noop), ('protocol', 'protocol', mapper.Noop
      ), ('protocol_port', 'protocol_port', mapper.Noop), ('connection_limit
      ', 'connection_limit', mapper.Noop), ('default_tls_container_ref', 'de
      fault_tls_container_ref', mapper.Noop), ('sni_container_refs', 'sni_co
      ntainer_refs', mapper.Noop), ('default_pool', 'default_pool_id', mappe
      r.Resource('neutron.lbaas.pool')), ('project', 'tenant_id', mapper.Res
      ource('project')), ('is_enabled', 'admin_state_up', mapper.Noop),]